@@ -12,16 +12,16 @@ from .lang import get_form
 
 MONTHS = {
     '01': ('январь', 'января', 'янв'),
-    '02': ('февраль', 'февраля', 'фев', 'февр'),
+    '02': ('февраль', 'февраля', 'февр', 'фев'),
     '03': ('март', 'марта', 'мар'),
     '04': ('апрель', 'апреля', 'апр'),
     '05': ('май', 'мая'),
     '06': ('июнь', 'июня', 'июн'),
     '07': ('июль', 'июля', 'июл'),
     '08': ('август', 'августа', 'авг'),
-    '09': ('сентябрь', 'сентября', 'сен', 'сент'),
+    '09': ('сентябрь', 'сентября', 'сент', 'сен'),
     '10': ('октябрь', 'октября', 'окт'),
-    '11': ('ноябрь', 'ноября', 'ноя', 'нояб'),
+    '11': ('ноябрь', 'ноября', 'нояб', 'ноя'),
     '12': ('декабрь', 'декабря', 'дек'),
 }
 DAYS_OF_WEEK = (
